--- title: Built-in targets ---

Target Type Name | Vendor | Name
--- | --- | ---
`cc3220sf` | Texas Instruments | CC3220SF
`cortex_m` | Generic | CoreSightTarget
`cy8c64_sysap` | Cypress | cy8c64_sysap
`cy8c64x5_cm0` | Cypress | cy8c64x5_cm0
`cy8c64x5_cm0_full_flash` | Cypress | cy8c64x5_cm0_full_flash
`cy8c64x5_cm4` | Cypress | cy8c64x5_cm4
`cy8c64x5_cm4_full_flash` | Cypress | cy8c64x5_cm4_full_flash
`cy8c64xa_cm0` | Cypress | cy8c64xA_cm0
`cy8c64xa_cm0_full_flash` | Cypress | cy8c64xA_cm0_full_flash
`cy8c64xa_cm4` | Cypress | cy8c64xA_cm4
`cy8c64xa_cm4_full_flash` | Cypress | cy8c64xA_cm4_full_flash
`cy8c64xx_cm0` | Cypress | cy8c64xx_cm0
`cy8c64xx_cm0_full_flash` | Cypress | cy8c64xx_cm0_full_flash
`cy8c64xx_cm0_nosmif` | Cypress | cy8c64xx_cm0_nosmif
`cy8c64xx_cm0_s25hx512t` | Cypress | cy8c64xx_cm0_s25hx512t
`cy8c64xx_cm4` | Cypress | cy8c64xx_cm4
`cy8c64xx_cm4_full_flash` | Cypress | cy8c64xx_cm4_full_flash
`cy8c64xx_cm4_nosmif` | Cypress | cy8c64xx_cm4_nosmif
`cy8c64xx_cm4_s25hx512t` | Cypress | cy8c64xx_cm4_s25hx512t
`cy8c6xx5` | Cypress | CY8C6xx5
`cy8c6xx7` | Cypress | CY8C6xx7
`cy8c6xx7_nosmif` | Cypress | CY8C6xx7_nosmif
`cy8c6xx7_s25fs512s` | Cypress | CY8C6xx7_S25FS512S
`cy8c6xxa` | Cypress | CY8C6xxA
`hc32f003` | HDSC | HC32F003
`hc32f005` | HDSC | HC32F005
`hc32f030` | HDSC | HC32F030
`hc32f072` | HDSC | HC32F072
`hc32f120x6` | HDSC | HC32F120x6TA
`hc32f120x8` | HDSC | HC32F120x8TA
`hc32f160xa` | HDSC | HC32F160xA
`hc32f160xc` | HDSC | HC32F160xC
`hc32f190` | HDSC | HC32F190
`hc32f196` | HDSC | HC32F196
`hc32f460xc` | HDSC | HC32F460xC
`hc32f460xe` | HDSC | HC32F460xE
`hc32f4a0xg` | HDSC | HC32F4A0xG
`hc32f4a0xi` | HDSC | HC32F4A0xI
`hc32l072` | HDSC | HC32L072
`hc32l073` | HDSC | HC32L073
`hc32l110` | HDSC | HC32L110
`hc32l130` | HDSC | HC32L130
`hc32l136` | HDSC | HC32L136
`hc32l190` | HDSC | HC32L190
`hc32l196` | HDSC | HC32L196
`hc32m120` | HDSC | HC32M120
`hc32m423xa` | HDSC | HC32M423xA
`k20d50m` | NXP | K20D50M
`k22f` | NXP | K22F
`k22fa12` | NXP | K22FA12
`k28f15` | NXP | K28F15
`k32l2b3` | NXP | K32L2B3
`k32w042s` | NXP | K32W042S
`k64f` | NXP | K64F
`k66f18` | NXP | K66F18
`k82f25615` | NXP | K82F25615
`ke15z7` | NXP | KE15Z7
`ke17z7` | NXP | KE17Z7
`ke18f16` | NXP | KE18F16
`kinetis` | NXP | Kinetis
`kl02z` | NXP | KL02Z
`kl05z` | NXP | KL05Z
`kl25z` | NXP | KL25Z
`kl26z` | NXP | KL26Z
`kl27z4` | NXP | KL27Z4
`kl28z` | NXP | KL28x
`kl43z4` | NXP | KL43Z4
`kl46z` | NXP | KL46Z
`kl82z7` | NXP | KL82Z7
`kv10z7` | NXP | KV10Z7
`kv11z7` | NXP | KV11Z7
`kw01z4` | NXP | KW01Z4
`kw24d5` | NXP | KW24D5
`kw36z4` | NXP | KW36Z4
`kw40z4` | NXP | KW40Z4
`kw41z4` | NXP | KW41Z4
`lpc11u24` | NXP | LPC11U24
`lpc11xx_32` | NXP | LPC11XX_32
`lpc1768` | NXP | LPC1768
`lpc4088` | NXP | LPC4088
`lpc4088dm` | NXP | LPC4088dm
`lpc4088qsb` | NXP | LPC4088qsb
`lpc4330` | NXP | LPC4330
`lpc54114` | NXP | LPC54114
`lpc54608` | NXP | LPC54608
`lpc5526` | NXP | LPC5526
`lpc55s28` | NXP | LPC55S28
`lpc55s36` | NXP | LPC55S36
`lpc55s69` | NXP | LPC55S69
`lpc800` | NXP | LPC800
`lpc824` | NXP | LPC824
`lpc845` | NXP | LPC845
`m2354kjfae` | Nuvoton | M2354KJFAE
`m252kg6ae` | Nuvoton | M252KG6AE
`m263kiaae` | Nuvoton | M263KIAAE
`m487jidae` | Nuvoton | M487JIDAE
`max32600` | Maxim | MAX32600
`max32620` | Maxim | MAX32620
`max32625` | Maxim | MAX32625
`max32630` | Maxim | MAX32630
`mimxrt1010` | NXP | MIMXRT1011xxxxx
`mimxrt1015` | NXP | MIMXRT1015xxxxx
`mimxrt1020` | NXP | MIMXRT1021xxxxx
`mimxrt1024` | NXP | MIMXRT1024xxxxx
`mimxrt1050` | NXP | MIMXRT1052xxxxB_hyperflash
`mimxrt1050_hyperflash` | NXP | MIMXRT1052xxxxB_hyperflash
`mimxrt1050_quadspi` | NXP | MIMXRT1052xxxxB_quadspi
`mimxrt1060` | NXP | MIMXRT1062xxxxA
`mimxrt1064` | NXP | MIMXRT1064xxxxA
`mimxrt1170_cm4` | NXP | MIMXRT1176xxxxx_CM4
`mimxrt1170_cm7` | NXP | MIMXRT1176xxxxx_CM7
`mps3_an522` | Arm | AN522
`mps3_an540` | Arm | AN540
`musca_a1` | Arm | MuscaA1
`musca_b1` | Arm | MuscaB1
`musca_s1` | Arm | MuscaS1
`ncs36510` | ONSemiconductor | NCS36510
`nrf51` | Nordic Semiconductor | NRF51
`nrf51822` | Nordic Semiconductor | NRF51
`nrf52` | Nordic Semiconductor | NRF52832
`nrf52832` | Nordic Semiconductor | NRF52832
`nrf52833` | Nordic Semiconductor | NRF52833
`nrf52840` | Nordic Semiconductor | NRF52840
`rp2040` | Raspberry Pi | RP2040Core0
`rp2040_core0` | Raspberry Pi | RP2040Core0
`rp2040_core1` | Raspberry Pi | RP2040Core1
`rtl8195am` | Realtek Semiconductor | RTL8195AM
`s5js100` | Samsung | S5JS100
`stm32f051` | STMicroelectronics | STM32F051
`stm32f103rc` | STMicroelectronics | STM32F103RC
`stm32f412xe` | STMicroelectronics | STM32F412xE
`stm32f412xg` | STMicroelectronics | STM32F412xG
`stm32f429xg` | STMicroelectronics | STM32F429xG
`stm32f429xi` | STMicroelectronics | STM32F429xI
`stm32f439xg` | STMicroelectronics | STM32F439xG
`stm32f439xi` | STMicroelectronics | STM32F439xI
`stm32f767zi` | STMicroelectronics | STM32F767xx
`stm32l031x6` | STMicroelectronics | STM32L031x6
`stm32l432kc` | STMicroelectronics | STM32L432xC
`stm32l475xc` | STMicroelectronics | STM32L475xC
`stm32l475xe` | STMicroelectronics | STM32L475xE
`stm32l475xg` | STMicroelectronics | STM32L475xG
`w7500` | WIZnet | W7500